==> Clownfish-CFC-0.4.4.tar.gz: Clownfish-CFC-0.4.4/include/CFC.h <==
/* Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "CFCBase.h"
#include "CFCCBlock.h"
#include "CFCClass.h"
#include "CFCDocuComment.h"
#include "CFCFile.h"
#include "CFCFileSpec.h"
#include "CFCFunction.h"
#include "CFCHierarchy.h"
#include "CFCMethod.h"
#include "CFCMemPool.h"
#include "CFCParamList.h"
#include "CFCParcel.h"
#include "CFCParser.h"
#include "CFCSymbol.h"
#include "CFCTest.h"
#include "CFCType.h"
#include "CFCUtil.h"
#include "CFCVariable.h"
#include "CFCVersion.h"

#include "CFCBindCore.h"
#include "CFCBindAliases.h"
#include "CFCBindClass.h"
#include "CFCBindFile.h"
#include "CFCBindFunction.h"
#include "CFCBindMethod.h"

#include "CFCPerl.h"
#include "CFCPerlSub.h"
#include "CFCPerlMethod.h"
#include "CFCPerlClass.h"
#include "CFCPerlConstructor.h"
#include "CFCPerlPod.h"
#include "CFCPerlTypeMap.h"

#include "CFCRuby.h"

==> Clownfish-CFC-0.4.99_1.tar.gz: Clownfish-CFC-0.4.99_1/include/CFC.h <==
/* Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "CFCBase.h"
#include "CFCCBlock.h"
#include "CFCCallable.h"
#include "CFCClass.h"
#include "CFCDocuComment.h"
#include "CFCDocument.h"
#include "CFCFile.h"
#include "CFCFileSpec.h"
#include "CFCFunction.h"
#include "CFCHierarchy.h"
#include "CFCMethod.h"
#include "CFCMemPool.h"
#include "CFCParamList.h"
#include "CFCParcel.h"
#include "CFCParser.h"
#include "CFCSymbol.h"
#include "CFCTest.h"
#include "CFCType.h"
#include "CFCUtil.h"
#include "CFCVariable.h"
#include "CFCVersion.h"

#include "CFCC.h"

#include "CFCBindCore.h"
#include "CFCBindAliases.h"
#include "CFCBindClass.h"
#include "CFCBindFile.h"
#include "CFCBindFunction.h"
#include "CFCBindMethod.h"
#include "CFCBindSpecs.h"

#include "CFCGo.h"
#include "CFCGoClass.h"

#include "CFCPerl.h"
#include "CFCPerlSub.h"
#include "CFCPerlMethod.h"
#include "CFCPerlClass.h"
#include "CFCPerlConstructor.h"
#include "CFCPerlPod.h"
#include "CFCPerlTypeMap.h"

#include "CFCPython.h"

#include "CFCRuby.h"
